From dd49b64aaeb3e3886430816199749685aed1cb86 Mon Sep 17 00:00:00 2001
From: Dmitri Naumov <dmitri.naumov@ufz.de>
Date: Thu, 4 Jan 2018 15:31:49 +0100
Subject: [PATCH] [MGTL] Fix comment and variable name.

---
 MeshGeoToolsLib/MeshNodeSearcher.cpp    | 4 ++--
 MeshGeoToolsLib/MeshNodesAlongSurface.h | 5 +++--
 2 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/MeshGeoToolsLib/MeshNodeSearcher.cpp b/MeshGeoToolsLib/MeshNodeSearcher.cpp
index c491b2411fd..fc19986e196 100644
--- a/MeshGeoToolsLib/MeshNodeSearcher.cpp
+++ b/MeshGeoToolsLib/MeshNodeSearcher.cpp
@@ -137,12 +137,12 @@ MeshNodesAlongSurface& MeshNodeSearcher::getMeshNodesAlongSurface(
     std::vector<MeshNodesAlongSurface*>::const_iterator it(_mesh_nodes_along_surfaces.begin());
     for (; it != _mesh_nodes_along_surfaces.end(); ++it) {
         if (&(*it)->getSurface() == &sfc) {
-            // we calculated mesh nodes for this polyline already
+            // we calculated mesh nodes on this surface already
             return *(*it);
         }
     }
 
-    // compute nodes (and supporting points) along polyline
+    // compute nodes (and supporting points) on surface
     _mesh_nodes_along_surfaces.push_back(
         new MeshNodesAlongSurface(_mesh,
                                   sfc,
diff --git a/MeshGeoToolsLib/MeshNodesAlongSurface.h b/MeshGeoToolsLib/MeshNodesAlongSurface.h
index ff09cfd099c..16b903f2683 100644
--- a/MeshGeoToolsLib/MeshNodesAlongSurface.h
+++ b/MeshGeoToolsLib/MeshNodesAlongSurface.h
@@ -39,14 +39,15 @@ public:
      * GeoLib::Surface object within a given search radius.
      * @param mesh Mesh the search will be performed on.
      * @param sfc Along the GeoLib::Surface sfc the mesh nodes are searched.
      * @param epsilon Euclidean distance tolerance value. Is the distance
      * between a mesh node and the surface smaller than that value it is a mesh
      * node near the surface.
      * @param search_all_nodes switch between searching all mesh nodes and
      * searching the base nodes.
      */
     MeshNodesAlongSurface(MeshLib::Mesh const& mesh, GeoLib::Surface const& sfc,
-                          double epsilon, SearchAllNodes search_all_nodes);
+                          double epsilon_radius,
+                          SearchAllNodes search_all_nodes);
 
     /// return the mesh object
     MeshLib::Mesh const& getMesh() const;
@@ -39,14 +39,15 @@ public:
      * @param mesh Mesh the search will be performed on.
      * @param sfc Along the GeoLib::Surface sfc the mesh nodes are searched.
-     * @param epsilon Euclidean distance tolerance value. Is the distance
+     * @param epsilon_radius Euclidean distance tolerance value. Is the distance
      * between a mesh node and the surface smaller than that value it is a mesh
      * node near the surface.
-- 
GitLab